# The main Greeter class
class Greeter
  attr_reader :language

  def initialize(language="English")
    @language = language
    @words = {
      "English" => "Hello",
      "Russian" => "Привет",
      "Uzbek" => "Salom"
    }
  end

  # Multi-lang greet
  #
  # Example:
  #   >> greeter = Greeter.new
  #   >> greeter.greet
  #   => "Hello" # "English" as default language
  #   >> # or
  #   >> greeter.greet("Uzbek")
  #   => "Salom"
  def greet(language=nil)
    @words[language || @language]
  end

  # Switch the language
  #
  # Example:
  #   >> greeter = Greeter.new
  #   >> greeter.language = "Russian"
  #   >> greeter.greet
  #   => "Привет" # Using "Russian" as default language
  def language=(language_name)
    raise "Uknown language" unless @words.include? language_name
    @language = language_name
  end

  # Add a new language and a word
  #
  # Example:
  #   >> greeter = Greeter.new
  #   >> greeter.add_language("Spanish", "Hola")
  #   >> greeter.greet("Spanish")
  #   => "Hola"
  def add_language(language, greeting)
    @words[language] = greeting
  end

  # Iterates over each word
  #
  # Example:
  #   >> greeter = Greeter.new
  #   >> greeter.each {|lang, word| greeter.greet(lang) }
  #   => ["English", "Russian", "Uzbek"]
  def each(&block)
    @words.each(&block)
  end
end
